"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _DropdownListItem = _interopRequireDefault(require("../Dropdown/DropdownListItem"));
var _Others = require("../Others");
var _utils = require("../../utils");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
function _extends() { return _extends = Object.assign ? Object.assign.bind() : function (n) { for (var e = 1; e < arguments.length; e++) { var t = arguments[e]; for (var r in t) ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]); } return n; }, _extends.apply(null, arguments); } /* eslint-disable react-native/no-inline-styles */
const DropdownSectionList = ({
  options,
  optionLabel,
  optionValue,
  isMultiple,
  isSearchable,
  selectedItems,
  selectedItem,
  handleMultipleSelections,
  handleSingleSelection,
  primaryColor,
  checkboxControls,
  listComponentStyles,
  listIndex,
  emptyListMessage,
  listEmptyComponent,
  ...rest
}) => {
  const [expandedSections, setExpandedSections] = (0, _react.useState)(new Set());

  /**
   * Expand all sections
   */
  (0, _react.useEffect)(() => {
    let initialState = new Set((0, _utils.extractPropertyFromArray)(options, 'title'));
    setExpandedSections(initialState);
  }, [options]);

  /**
   * @param title
   */
  const handleToggleListExpansion = title => {
    setExpandedSections(expandedSectionsState => {
      // Using Set here but you can use an array too
      const next = new Set(expandedSectionsState);
      if (next.has(title)) {
        next.delete(title);
      } else {
        next.add(title);
      }
      return next;
    });
  };

  /**
   * @description Scroll to item location
   */

  const sectionlistRef = (0, _react.useRef)(null);
  const scrollToLocation = index => {
    sectionlistRef?.current?.scrollToLocation({
      sectionIndex: index.sectionIndex,
      animated: true,
      itemIndex: index.itemIndex
    });
  };
  (0, _react.useEffect)(() => {
    if (listIndex.itemIndex >= 0 && listIndex.sectionIndex >= 0) {
      scrollToLocation(listIndex);
    }
  }, [listIndex]);
  const itemSeparator = () => /*#__PURE__*/_react.default.createElement(_Others.ItemSeparatorComponent, {
    itemSeparatorStyle: listComponentStyles?.itemSeparatorStyle
  });
  return /*#__PURE__*/_react.default.createElement(_reactNative.SectionList, _extends({
    testID: "react-native-input-select-section-list",
    sections: options,
    extraData: isMultiple ? selectedItems : selectedItem,
    initialNumToRender: 5,
    ListEmptyComponent: listEmptyComponent || /*#__PURE__*/_react.default.createElement(_Others.ListEmptyComponent, {
      listEmptyComponentStyle: listComponentStyles?.listEmptyComponentStyle,
      emptyListMessage: emptyListMessage
    }),
    contentContainerStyle: [isSearchable ? {
      paddingTop: 0
    } : styles.contentContainerStyle],
    ItemSeparatorComponent: itemSeparator,
    renderItem: item => _renderItem(item, {
      optionLabel,
      optionValue,
      isMultiple,
      selectedOption: isMultiple ? selectedItems : selectedItem,
      onChange: isMultiple ? handleMultipleSelections : handleSingleSelection,
      primaryColor,
      checkboxControls,
      expandedSections
    }),
    renderSectionHeader: ({
      section: {
        title
      }
    }) => /*#__PURE__*/_react.default.createElement(_Others.SectionHeaderTitle, {
      title: title,
      sectionHeaderStyle: listComponentStyles?.sectionHeaderStyle,
      onPress: () => handleToggleListExpansion(title),
      isExpanded: expandedSections.has(title)
    }),
    keyExtractor: (_item, index) => `Options${index}`,
    stickySectionHeadersEnabled: false,
    ref: sectionlistRef,
    onScrollToIndexFailed: () => {
      setTimeout(() => {
        scrollToLocation(listIndex);
      }, 500);
    }
  }, rest));
};
const _renderItem = ({
  section: {
    title
  },
  item
}, props) => {
  const isExpanded = props?.expandedSections.has(title);

  //return null if it is not expanded
  if (!isExpanded) return null;
  return /*#__PURE__*/_react.default.createElement(_DropdownListItem.default, {
    item: item,
    optionLabel: props.optionLabel,
    optionValue: props.optionValue,
    isMultiple: props.isMultiple,
    selectedOption: props.selectedOption,
    onChange: props.onChange,
    primaryColor: props.primaryColor,
    checkboxControls: props.checkboxControls
  });
};
const styles = _reactNative.StyleSheet.create({
  contentContainerStyle: {
    paddingTop: 20
  }
});
var _default = exports.default = DropdownSectionList;
//# sourceMappingURL=DropdownSectionList.js.map