"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useModal = void 0;
var _react = require("react");
var _reactNative = require("react-native");
const useModal = ({
  resetOptionsRelatedState,
  disabled,
  modalControls
}) => {
  const [isVisible, setIsVisible] = (0, _react.useState)(false);
  const openModal = () => {
    if (disabled) return;
    setIsVisible(true);
    resetOptionsRelatedState();
  };
  const closeModal = () => {
    setIsVisible(false);
    resetOptionsRelatedState();

    // iOS supports the onDismiss prop but android does not, so we do this explicitly here
    // https://reactnative.dev/docs/modal#ondismiss-ios
    if (_reactNative.Platform.OS === 'android') {
      modalControls?.modalProps?.onDismiss?.();
    }
  };
  return {
    isVisible,
    openModal: () => openModal(),
    closeModal: () => closeModal()
  };
};
exports.useModal = useModal;
//# sourceMappingURL=use-modal.js.map