"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useSearch = void 0;
var _react = require("react");
var _utils = require("../utils");
const useSearch = ({
  initialOptions,
  optionLabel,
  optionValue,
  searchCallback
}) => {
  const [searchValue, setSearchValue] = (0, _react.useState)('');
  const [filteredOptions, setFilteredOptions] = (0, _react.useState)(initialOptions);
  const resetOptionsToDefault = options => {
    setFilteredOptions(options);
  };
  (0, _react.useEffect)(() => {
    resetOptionsToDefault(initialOptions);
    return () => {};
  }, [initialOptions]);
  const searchFlatList = (0, _react.useCallback)((flatList, regexFilter) => {
    return flatList.filter(item => {
      return item[optionLabel]?.toString().toLowerCase().search(regexFilter) !== -1 || item[optionValue]?.toString().toLowerCase().search(regexFilter) !== -1;
    });
  }, [optionLabel, optionValue]);
  const searchSectionList = (0, _react.useCallback)((sectionList, regexFilter) => {
    return sectionList.map(listItem => {
      // A section list is the combination of several flat lists
      const filteredData = searchFlatList(listItem.data, regexFilter);
      return {
        ...listItem,
        data: filteredData
      };
    });
  }, [searchFlatList]);
  const isSection = (0, _utils.isSectionList)(initialOptions);
  const onSearch = (0, _react.useCallback)(value => {
    searchCallback?.(value);
    const searchText = (0, _utils.escapeRegExp)(value).toLowerCase().trim();
    const regexFilter = new RegExp(searchText, 'i');
    const searchResults = isSection ? searchSectionList(initialOptions, regexFilter) : searchFlatList(initialOptions, regexFilter);
    setFilteredOptions(searchResults);
  }, [initialOptions, isSection, searchCallback, searchFlatList, searchSectionList]);
  (0, _react.useEffect)(() => {
    if (searchValue) {
      onSearch(searchValue);
    } else {
      resetOptionsToDefault(initialOptions);
    }
  }, [initialOptions, onSearch, searchValue]);
  return {
    searchValue,
    setSearchValue,
    filteredOptions,
    setFilteredOptions,
    isSectionList: isSection
  };
};
exports.useSearch = useSearch;
//# sourceMappingURL=use-search.js.map