"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useSelectAll = void 0;
var _react = require("react");
var _utils = require("../utils");
const useSelectAll = ({
  options,
  selectedItems,
  isMultiple,
  onValueChange,
  listControls,
  optionValue
}) => {
  const [selectAll, setSelectAll] = (0, _react.useState)(false);

  /**
   * @description Handle "Select All" logic
   */
  const handleSelectAll = (0, _react.useCallback)(() => {
    setSelectAll(prevVal => {
      let selectedValues = [];

      // Remove disabled items from selection
      const filteredOptions = (0, _utils.removeDisabledItems)(options);

      // if everything has not been selected, select all the values in the list
      if (!prevVal) {
        selectedValues = filteredOptions.map(obj => obj[optionValue]);
      }
      onValueChange(selectedValues); // Send selected values to parent
      return !prevVal;
    });
    if (typeof listControls?.selectAllCallback === 'function' && !selectAll) {
      listControls.selectAllCallback();
    }
    if (typeof listControls?.unselectAllCallback === 'function' && selectAll) {
      listControls.unselectAllCallback();
    }
  }, [options, optionValue, listControls, selectAll, onValueChange]);

  /**
   * Check if all items are selected
   */
  const checkSelectAll = (0, _react.useCallback)(() => {
    if ((0, _utils.removeDisabledItems)(options)?.length === selectedItems?.length) {
      setSelectAll(true);
    } else {
      setSelectAll(false);
    }
  }, [options, selectedItems]);

  /**
   * if the user decides to select the options one by one, this hook
   * runs to check if everything has been selected so that the `selectAll checkbox` can be selected
   */
  (0, _react.useEffect)(() => {
    if (isMultiple) {
      checkSelectAll();
    }
  }, [checkSelectAll, isMultiple, selectedItems]);
  return {
    selectAll,
    handleSelectAll
  };
};
exports.useSelectAll = useSelectAll;
//# sourceMappingURL=use-select-all.js.map