"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.DropdownSelect = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _Input = _interopRequireDefault(require("./components/Input"));
var _CheckBox = _interopRequireDefault(require("./components/CheckBox"));
var _Dropdown = _interopRequireDefault(require("./components/Dropdown/Dropdown"));
var _DropdownFlatList = _interopRequireDefault(require("./components/List/DropdownFlatList"));
var _DropdownSectionList = _interopRequireDefault(require("./components/List/DropdownSectionList"));
var _CustomModal = _interopRequireDefault(require("./components/CustomModal"));
var _colors = require("./styles/colors");
var _constants = require("./constants");
var _utils = require("./utils");
var _hooks = require("./hooks");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
function _extends() { return _extends = Object.assign ? Object.assign.bind() : function (n) { for (var e = 1; e < arguments.length; e++) { var t = arguments[e]; for (var r in t) ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]); } return n; }, _extends.apply(null, arguments); }
const DropdownSelect = exports.DropdownSelect = /*#__PURE__*/(0, _react.forwardRef)(({
  testID,
  placeholder,
  label,
  error,
  helperText,
  options,
  optionLabel = _constants.DEFAULT_OPTION_LABEL,
  optionValue = _constants.DEFAULT_OPTION_VALUE,
  onValueChange,
  isMultiple = false,
  selectedValue = isMultiple ? [] : '',
  isSearchable,
  dropdownIcon,
  labelStyle,
  placeholderStyle,
  dropdownStyle,
  dropdownIconStyle,
  dropdownContainerStyle,
  dropdownErrorStyle,
  dropdownErrorTextStyle,
  dropdownHelperTextStyle,
  selectedItemStyle,
  multipleSelectedItemStyle,
  primaryColor = _colors.colors.gray,
  disabled = false,
  listHeaderComponent,
  listFooterComponent,
  listComponentStyles,
  listEmptyComponent,
  listControls,
  searchControls,
  modalControls,
  checkboxControls,
  autoCloseOnSelect = true,
  maxSelectableItems,
  ...rest
}, ref) => {
  /*===========================================
   * Expose the methods to the parent using
   * useImperativeHandle
   *==========================================*/
  (0, _react.useImperativeHandle)(ref, () => ({
    open: () => openModal(),
    close: () => closeModal()
  }));

  /*===========================================
   * Search
   *==========================================*/
  const {
    searchValue,
    setSearchValue,
    setFilteredOptions,
    filteredOptions,
    isSectionList
  } = (0, _hooks.useSearch)({
    initialOptions: options,
    optionLabel,
    optionValue,
    searchCallback: (0, _react.useCallback)(value => searchControls?.searchCallback?.(value), [searchControls])
  });

  /*===========================================
   * setIndexOfSelectedItem - For ScrollToIndex
   *==========================================*/
  const {
    listIndex,
    setListIndex,
    setIndexOfSelectedItem
  } = (0, _hooks.useIndexOfSelectedItem)({
    options,
    optionLabel,
    isSectionList
  });

  /*===========================================
   * Reset component states
   *==========================================*/
  const resetOptionsRelatedState = (0, _react.useCallback)(() => {
    setSearchValue('');
    setFilteredOptions(options);
    setListIndex({
      itemIndex: -1,
      sectionIndex: -1
    });
  }, [options, setFilteredOptions, setListIndex, setSearchValue]);

  /*===========================================
   * Modal
   *==========================================*/
  const {
    isVisible,
    openModal,
    closeModal
  } = (0, _hooks.useModal)({
    resetOptionsRelatedState,
    disabled,
    modalControls
  });

  /*===========================================
   * Single and multiple selection Hook
   *==========================================*/
  const {
    selectedItem,
    selectedItems,
    setSelectedItem,
    setSelectedItems,
    handleSingleSelection,
    handleMultipleSelections
  } = (0, _hooks.useSelectionHandler)({
    initialSelectedValue: selectedValue,
    isMultiple,
    maxSelectableItems,
    onValueChange,
    closeModal: () => closeModal(),
    autoCloseOnSelect
  });
  (0, _react.useEffect)(() => {
    isMultiple ? setSelectedItems(selectedValue) : setSelectedItem(selectedValue);
    return () => {};
  }, [selectedValue, setSelectedItems, setSelectedItem, isMultiple, onValueChange]);

  /*===========================================
   * List type
   *==========================================*/
  const ListTypeComponent = isSectionList ? _DropdownSectionList.default : _DropdownFlatList.default;
  const modifiedSectionData = (0, _utils.extractPropertyFromArray)(filteredOptions, 'data')?.flat();

  /**
   * `options` is the original array, it never changes. (Do not use except you really need the original array) .
   * `filteredOptions` is a copy of options but can be mutated by `setFilteredOptions`, as a result, the value may change.
   * `modifiedOptions` should only be used for computations. It has the same structure for both `FlatList` and `SectionList`
   */
  const modifiedOptions = isSectionList ? modifiedSectionData : filteredOptions;

  /*===========================================
   * Select all Hook
   *==========================================*/
  const {
    selectAll,
    handleSelectAll
  } = (0, _hooks.useSelectAll)({
    options: modifiedOptions,
    selectedItems,
    isMultiple,
    onValueChange,
    listControls,
    optionValue
  });
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_Dropdown.default, _extends({
    testID: testID,
    label: label,
    placeholder: placeholder,
    helperText: helperText,
    error: error,
    labelsOfSelectedItems: (0, _utils.getLabelsOfSelectedItems)({
      isMultiple,
      optionLabel,
      optionValue,
      selectedItem,
      selectedItems,
      modifiedOptions
    }),
    selectedItem: selectedItem,
    selectedItems: selectedItems,
    openModal: () => openModal(),
    closeModal: () => closeModal(),
    labelStyle: labelStyle,
    dropdownIcon: dropdownIcon,
    dropdownStyle: dropdownStyle,
    dropdownIconStyle: dropdownIconStyle,
    dropdownContainerStyle: dropdownContainerStyle,
    dropdownErrorStyle: dropdownErrorStyle,
    dropdownErrorTextStyle: dropdownErrorTextStyle,
    dropdownHelperTextStyle: dropdownHelperTextStyle,
    selectedItemStyle: selectedItemStyle,
    multipleSelectedItemStyle: multipleSelectedItemStyle,
    isMultiple: isMultiple,
    primaryColor: primaryColor,
    disabled: disabled,
    placeholderStyle: placeholderStyle,
    setIndexOfSelectedItem: setIndexOfSelectedItem
  }, rest)), /*#__PURE__*/_react.default.createElement(_CustomModal.default, {
    visible: isVisible,
    onRequestClose: () => closeModal(),
    modalControls: modalControls
  }, /*#__PURE__*/_react.default.createElement(ListTypeComponent, {
    ListHeaderComponent: /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, isSearchable && /*#__PURE__*/_react.default.createElement(_Input.default, _extends({
      value: searchValue,
      onChangeText: text => setSearchValue(text),
      style: searchControls?.textInputStyle,
      primaryColor: primaryColor,
      textInputContainerStyle: searchControls?.textInputContainerStyle,
      placeholder: searchControls?.textInputProps?.placeholder || 'Search',
      "aria-label": searchControls?.textInputProps?.placeholder || 'Search'
    }, searchControls?.textInputProps)), listHeaderComponent, !listControls?.hideSelectAll && isMultiple && modifiedOptions?.length > 1 && /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      style: styles.optionsContainerStyle
    }, /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
      accessible: false
    }, /*#__PURE__*/_react.default.createElement(_CheckBox.default, {
      value: selectAll,
      label: selectAll ? listControls?.unselectAllText || 'Clear all' : listControls?.selectAllText || 'Select all',
      onChange: () => handleSelectAll(),
      primaryColor: primaryColor,
      checkboxControls: checkboxControls
    })))),
    ListFooterComponent: listFooterComponent,
    listComponentStyles: listComponentStyles,
    options: filteredOptions,
    optionLabel: optionLabel,
    optionValue: optionValue,
    isMultiple: isMultiple,
    isSearchable: isSearchable,
    selectedItems: selectedItems,
    selectedItem: selectedItem,
    handleMultipleSelections: handleMultipleSelections,
    handleSingleSelection: handleSingleSelection,
    primaryColor: primaryColor,
    checkboxControls: checkboxControls,
    listIndex: listIndex,
    listEmptyComponent: listEmptyComponent,
    emptyListMessage: listControls?.emptyListMessage,
    keyboardShouldPersistTaps: listControls?.keyboardShouldPersistTaps
  })));
});
const styles = _reactNative.StyleSheet.create({
  optionsContainerStyle: {
    paddingHorizontal: 20,
    paddingVertical: 10,
    flexDirection: 'row'
  }
});
var _default = exports.default = DropdownSelect;
//# sourceMappingURL=index.js.map