import React from 'react';
import { Pressable, Text, StyleSheet, Image, View } from 'react-native';
import { colors } from '../../styles/colors';
import { CHECKBOX_SIZE } from '../../constants';
const CheckBox = ({
  label,
  value,
  disabled,
  primaryColor,
  checkboxControls,
  onChange
}) => {
  const {
    checkboxSize,
    checkboxComponent,
    checkboxDisabledStyle,
    checkboxStyle,
    checkboxUnselectedColor,
    checkboxLabelStyle
  } = checkboxControls ?? {};
  const fillColor = {
    backgroundColor: disabled ? checkboxDisabledStyle?.backgroundColor || colors.disabled : value ? checkboxStyle?.backgroundColor || primaryColor : checkboxUnselectedColor || 'white',
    borderColor: disabled ? checkboxDisabledStyle?.borderColor || colors.disabled : checkboxStyle?.borderColor || styles.checkbox.borderColor
  };
  label = typeof label === 'object' ? label : String(label);
  return /*#__PURE__*/React.createElement(Pressable, {
    onPress: onChange ? () => onChange(!value) : null,
    style: [styles.checkboxContainer],
    disabled: disabled,
    "aria-label": typeof label === 'string' ? label : ''
  }, /*#__PURE__*/React.createElement(View, {
    style: [styles.checkbox, checkboxStyle, fillColor],
    "aria-checked": value
  }, checkboxComponent || /*#__PURE__*/React.createElement(Image, {
    source: require('../../asset/check.png'),
    style: [{
      height: checkboxSize || CHECKBOX_SIZE,
      width: checkboxSize || CHECKBOX_SIZE
    }]
  })), label && label !== '' && /*#__PURE__*/React.createElement(Text, {
    style: [checkboxLabelStyle, styles.labelStyle]
  }, label));
};
const styles = StyleSheet.create({
  checkboxContainer: {
    flexDirection: 'row',
    flexWrap: 'nowrap',
    alignItems: 'center'
  },
  checkbox: {
    padding: 4,
    borderWidth: 1,
    borderStyle: 'solid',
    borderRadius: 4,
    borderColor: 'black'
  },
  labelStyle: {
    marginLeft: 10
  }
});
export default CheckBox;
//# sourceMappingURL=index.js.map