import { useState, useCallback, useEffect } from 'react';
import { escapeRegExp, isSectionList } from '../utils';
export const useSearch = ({
  initialOptions,
  optionLabel,
  optionValue,
  searchCallback
}) => {
  const [searchValue, setSearchValue] = useState('');
  const [filteredOptions, setFilteredOptions] = useState(initialOptions);
  const resetOptionsToDefault = options => {
    setFilteredOptions(options);
  };
  useEffect(() => {
    resetOptionsToDefault(initialOptions);
    return () => {};
  }, [initialOptions]);
  const searchFlatList = useCallback((flatList, regexFilter) => {
    return flatList.filter(item => {
      return item[optionLabel]?.toString().toLowerCase().search(regexFilter) !== -1 || item[optionValue]?.toString().toLowerCase().search(regexFilter) !== -1;
    });
  }, [optionLabel, optionValue]);
  const searchSectionList = useCallback((sectionList, regexFilter) => {
    return sectionList.map(listItem => {
      // A section list is the combination of several flat lists
      const filteredData = searchFlatList(listItem.data, regexFilter);
      return {
        ...listItem,
        data: filteredData
      };
    });
  }, [searchFlatList]);
  const isSection = isSectionList(initialOptions);
  const onSearch = useCallback(value => {
    searchCallback?.(value);
    const searchText = escapeRegExp(value).toLowerCase().trim();
    const regexFilter = new RegExp(searchText, 'i');
    const searchResults = isSection ? searchSectionList(initialOptions, regexFilter) : searchFlatList(initialOptions, regexFilter);
    setFilteredOptions(searchResults);
  }, [initialOptions, isSection, searchCallback, searchFlatList, searchSectionList]);
  useEffect(() => {
    if (searchValue) {
      onSearch(searchValue);
    } else {
      resetOptionsToDefault(initialOptions);
    }
  }, [initialOptions, onSearch, searchValue]);
  return {
    searchValue,
    setSearchValue,
    filteredOptions,
    setFilteredOptions,
    isSectionList: isSection
  };
};
//# sourceMappingURL=use-search.js.map