function _extends() { return _extends = Object.assign ? Object.assign.bind() : function (n) { for (var e = 1; e < arguments.length; e++) { var t = arguments[e]; for (var r in t) ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]); } return n; }, _extends.apply(null, arguments); }
import React, { forwardRef, useCallback, useEffect, useImperativeHandle } from 'react';
import { TouchableOpacity, StyleSheet, View } from 'react-native';
import Input from './components/Input';
import CheckBox from './components/CheckBox';
import Dropdown from './components/Dropdown/Dropdown';
import DropdownFlatList from './components/List/DropdownFlatList';
import DropdownSectionList from './components/List/DropdownSectionList';
import CustomModal from './components/CustomModal';
import { colors } from './styles/colors';
import { DEFAULT_OPTION_LABEL, DEFAULT_OPTION_VALUE } from './constants';
import { extractPropertyFromArray, getLabelsOfSelectedItems } from './utils';
import { useSelectionHandler, useModal, useSearch, useIndexOfSelectedItem, useSelectAll } from './hooks';
export const DropdownSelect = /*#__PURE__*/forwardRef(({
  testID,
  placeholder,
  label,
  error,
  helperText,
  options,
  optionLabel = DEFAULT_OPTION_LABEL,
  optionValue = DEFAULT_OPTION_VALUE,
  onValueChange,
  isMultiple = false,
  selectedValue = isMultiple ? [] : '',
  isSearchable,
  dropdownIcon,
  labelStyle,
  placeholderStyle,
  dropdownStyle,
  dropdownIconStyle,
  dropdownContainerStyle,
  dropdownErrorStyle,
  dropdownErrorTextStyle,
  dropdownHelperTextStyle,
  selectedItemStyle,
  multipleSelectedItemStyle,
  primaryColor = colors.gray,
  disabled = false,
  listHeaderComponent,
  listFooterComponent,
  listComponentStyles,
  listEmptyComponent,
  listControls,
  searchControls,
  modalControls,
  checkboxControls,
  autoCloseOnSelect = true,
  maxSelectableItems,
  ...rest
}, ref) => {
  /*===========================================
   * Expose the methods to the parent using
   * useImperativeHandle
   *==========================================*/
  useImperativeHandle(ref, () => ({
    open: () => openModal(),
    close: () => closeModal()
  }));

  /*===========================================
   * Search
   *==========================================*/
  const {
    searchValue,
    setSearchValue,
    setFilteredOptions,
    filteredOptions,
    isSectionList
  } = useSearch({
    initialOptions: options,
    optionLabel,
    optionValue,
    searchCallback: useCallback(value => searchControls?.searchCallback?.(value), [searchControls])
  });

  /*===========================================
   * setIndexOfSelectedItem - For ScrollToIndex
   *==========================================*/
  const {
    listIndex,
    setListIndex,
    setIndexOfSelectedItem
  } = useIndexOfSelectedItem({
    options,
    optionLabel,
    isSectionList
  });

  /*===========================================
   * Reset component states
   *==========================================*/
  const resetOptionsRelatedState = useCallback(() => {
    setSearchValue('');
    setFilteredOptions(options);
    setListIndex({
      itemIndex: -1,
      sectionIndex: -1
    });
  }, [options, setFilteredOptions, setListIndex, setSearchValue]);

  /*===========================================
   * Modal
   *==========================================*/
  const {
    isVisible,
    openModal,
    closeModal
  } = useModal({
    resetOptionsRelatedState,
    disabled,
    modalControls
  });

  /*===========================================
   * Single and multiple selection Hook
   *==========================================*/
  const {
    selectedItem,
    selectedItems,
    setSelectedItem,
    setSelectedItems,
    handleSingleSelection,
    handleMultipleSelections
  } = useSelectionHandler({
    initialSelectedValue: selectedValue,
    isMultiple,
    maxSelectableItems,
    onValueChange,
    closeModal: () => closeModal(),
    autoCloseOnSelect
  });
  useEffect(() => {
    isMultiple ? setSelectedItems(selectedValue) : setSelectedItem(selectedValue);
    return () => {};
  }, [selectedValue, setSelectedItems, setSelectedItem, isMultiple, onValueChange]);

  /*===========================================
   * List type
   *==========================================*/
  const ListTypeComponent = isSectionList ? DropdownSectionList : DropdownFlatList;
  const modifiedSectionData = extractPropertyFromArray(filteredOptions, 'data')?.flat();

  /**
   * `options` is the original array, it never changes. (Do not use except you really need the original array) .
   * `filteredOptions` is a copy of options but can be mutated by `setFilteredOptions`, as a result, the value may change.
   * `modifiedOptions` should only be used for computations. It has the same structure for both `FlatList` and `SectionList`
   */
  const modifiedOptions = isSectionList ? modifiedSectionData : filteredOptions;

  /*===========================================
   * Select all Hook
   *==========================================*/
  const {
    selectAll,
    handleSelectAll
  } = useSelectAll({
    options: modifiedOptions,
    selectedItems,
    isMultiple,
    onValueChange,
    listControls,
    optionValue
  });
  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Dropdown, _extends({
    testID: testID,
    label: label,
    placeholder: placeholder,
    helperText: helperText,
    error: error,
    labelsOfSelectedItems: getLabelsOfSelectedItems({
      isMultiple,
      optionLabel,
      optionValue,
      selectedItem,
      selectedItems,
      modifiedOptions
    }),
    selectedItem: selectedItem,
    selectedItems: selectedItems,
    openModal: () => openModal(),
    closeModal: () => closeModal(),
    labelStyle: labelStyle,
    dropdownIcon: dropdownIcon,
    dropdownStyle: dropdownStyle,
    dropdownIconStyle: dropdownIconStyle,
    dropdownContainerStyle: dropdownContainerStyle,
    dropdownErrorStyle: dropdownErrorStyle,
    dropdownErrorTextStyle: dropdownErrorTextStyle,
    dropdownHelperTextStyle: dropdownHelperTextStyle,
    selectedItemStyle: selectedItemStyle,
    multipleSelectedItemStyle: multipleSelectedItemStyle,
    isMultiple: isMultiple,
    primaryColor: primaryColor,
    disabled: disabled,
    placeholderStyle: placeholderStyle,
    setIndexOfSelectedItem: setIndexOfSelectedItem
  }, rest)), /*#__PURE__*/React.createElement(CustomModal, {
    visible: isVisible,
    onRequestClose: () => closeModal(),
    modalControls: modalControls
  }, /*#__PURE__*/React.createElement(ListTypeComponent, {
    ListHeaderComponent: /*#__PURE__*/React.createElement(React.Fragment, null, isSearchable && /*#__PURE__*/React.createElement(Input, _extends({
      value: searchValue,
      onChangeText: text => setSearchValue(text),
      style: searchControls?.textInputStyle,
      primaryColor: primaryColor,
      textInputContainerStyle: searchControls?.textInputContainerStyle,
      placeholder: searchControls?.textInputProps?.placeholder || 'Search',
      "aria-label": searchControls?.textInputProps?.placeholder || 'Search'
    }, searchControls?.textInputProps)), listHeaderComponent, !listControls?.hideSelectAll && isMultiple && modifiedOptions?.length > 1 && /*#__PURE__*/React.createElement(View, {
      style: styles.optionsContainerStyle
    }, /*#__PURE__*/React.createElement(TouchableOpacity, {
      accessible: false
    }, /*#__PURE__*/React.createElement(CheckBox, {
      value: selectAll,
      label: selectAll ? listControls?.unselectAllText || 'Clear all' : listControls?.selectAllText || 'Select all',
      onChange: () => handleSelectAll(),
      primaryColor: primaryColor,
      checkboxControls: checkboxControls
    })))),
    ListFooterComponent: listFooterComponent,
    listComponentStyles: listComponentStyles,
    options: filteredOptions,
    optionLabel: optionLabel,
    optionValue: optionValue,
    isMultiple: isMultiple,
    isSearchable: isSearchable,
    selectedItems: selectedItems,
    selectedItem: selectedItem,
    handleMultipleSelections: handleMultipleSelections,
    handleSingleSelection: handleSingleSelection,
    primaryColor: primaryColor,
    checkboxControls: checkboxControls,
    listIndex: listIndex,
    listEmptyComponent: listEmptyComponent,
    emptyListMessage: listControls?.emptyListMessage,
    keyboardShouldPersistTaps: listControls?.keyboardShouldPersistTaps
  })));
});
const styles = StyleSheet.create({
  optionsContainerStyle: {
    paddingHorizontal: 20,
    paddingVertical: 10,
    flexDirection: 'row'
  }
});
export default DropdownSelect;
//# sourceMappingURL=index.js.map